@@ -1,4 +1,5 @@
 from .attr import MetaAttr
+from functools import partial
 from six import with_metaclass
 import json
 
@@ -20,9 +21,10 @@ class ARMMetaObject(MetaAttr):
 
 class ARMObject(with_metaclass(ARMMetaObject)):
     __spec__ = {}
+    _session = None
     field_map = set()
 
-    def __new__(cls, **obj):
+    def __new__(cls, _session=None, **obj):
         if 'id' in obj:
             uid = obj['id']
             if uid in _object_cache[cls]:
@@ -30,7 +32,8 @@ class ARMObject(with_metaclass(ARMMetaObject)):
                 return _object_cache[cls][uid]
         return super(ARMObject, cls).__new__(cls)
 
-    def __init__(self, **obj):
+    def __init__(self, _session=None, **obj):
+        self._session = _session
         self._set_data(dict(self.__spec__.get('polymorphic') or {}, **obj))
 
     def __getattr__(self, attr):
@@ -40,7 +43,7 @@ class ARMObject(with_metaclass(ARMMetaObject)):
 
     def _set_data(self, obj):
         self._data = obj
-        self._data = data2object(self._data, self.field_map)
+        self._data = data2object(self._data, self.field_map, self._session)
         if 'id' in obj:
             _object_cache[self.__class__][obj['id']] = self
 
@@ -51,39 +54,68 @@ class ARMObject(with_metaclass(ARMMetaObject)):
         return object2data(self._data)
 
     def update(self, **update):
-        ARMRequest(self.__class__)._request('put', id=self.id, json=update)
+        ARMRequest(self.__class__, self._session)._request('put', id=self.id, json=update)
 
     def delete(self):
-        ARMRequest(self.__class__)._request('delete', id=self.id)
+        ARMRequest(self.__class__, self._session)._request('delete', id=self.id)
 
     @classmethod
     def get(cls, id, *args, **kwargs):
-        return ARMRequest(cls).get(id, *args, **kwargs)
+        return ARMRequest(cls, kwargs.pop('_session', None)).get(id, *args, **kwargs)
 
     @classmethod
     def filter_by(cls, *filters, **kw_filters):
-        return ARMRequest(cls)\
+        return ARMRequest(cls, kw_filters.pop('_session', None))\
             .filter_by(*filters, **dict(cls.__spec__.get('polymorphic') or {}, **kw_filters))
 
     @classmethod
     def create(cls, objects=None, **values):
-        return ARMRequest(cls)\
+        return ARMRequest(cls, values.pop('_session', None))\
             .create(objects, **values)
 
     @classmethod
-    def select(cls, *fields):
-        return ARMRequest(cls).select(*fields)\
+    def select(cls, *fields, _session=None):
+        return ARMRequest(cls, _session).select(*fields)\
             .filter_by(**dict(cls.__spec__.get('polymorphic') or {}))
 
     @classmethod
     def update_all(cls, objects=None, **values):
-        return ARMRequest(cls)\
+        return ARMRequest(cls, values.pop('_session', None))\
             .update(objects, **values)
 
     @classmethod
     def delete_all(cls, objects=None, **values):
-        return ARMRequest(cls)\
+        return ARMRequest(cls, values.pop('_session', None))\
             .delete(objects, **values)
 
+class ARMMetaObjectWrapper(object):
+    def __getattr__(cls, key):
+        if key == 'Foo':
+            return cls._foo_func()
+        elif key == 'Bar':
+            return cls._bar_func()
+        raise AttributeError(key)
+
+class ARMObjectWrapper(object):
+    def __init__(self, Object, session):
+        self.Object = Object
+        self.session = session
+
+    def __call__(self, *args, **kwargs):
+        obj = self.Object(*args, **kwargs)
+        obj._session = self.session
+        return obj
+
+    def call(self, __name, *args, **kwargs):
+        kwargs['_session'] = self.session
+        return getattr(self.Object, __name)(*args, **kwargs)
+
+    def __getattr__(self, name):
+        if name in ('get', 'filter_by', 'create', 'select', 'update_all', 'delete_all'):
+            return partial(self.call, name)
+
+        return getattr(self.Object, name)
+
+
 from .request import ARMRequest
 from ..utils import object2data, data2object
